@@ -259,8 +259,9 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
             self._tls_session.close()
             resp.raise_for_status()
             return True
-        except exceptions.RequestException:
-            return False
+        except exceptions.RequestException as e:
+            raise KempTechApiException("Enable API failed because of: {}".format(
+                e.__class__.__name__), is_xml_msg=False)
 
     def stats(self):
         response = self._get('/stats')
@@ -462,7 +463,7 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
             self.alsi_license(kempid['username'], kempid['password'])
             self.initial_password(new_password)
         else:
-            print("Please license before proceeding.")
+            raise KempTechApiException("Please license before proceeding.")
 
     def get_eula(self):
         api = "/readeula"
@@ -1216,10 +1217,6 @@ class LoadMaster(BaseKempAppliance):
         response = self._get("/listvs")
         data = get_data(response)
         virtual_services = []
-        # if there is no VS key, build_virtual_services will fail with a
-        # ValidationError, which is the best we can do for now
-        # (without changing the upstream code and raising an exception earlier,
-        # possibly retrying)
         services = data.get('VS', [])
         services = cast_to_list(services)
         for service in services:
