@@ -3,7 +3,11 @@ from unittest import skip
 from nose.tools import (
     assert_equal, assert_raises, assert_true,
     assert_is_none, assert_not_in, assert_greater, assert_less,
-    assert_greater_equal, assert_less_equal, assert_not_equal, assert_false)
+    assert_greater_equal, assert_less_equal, assert_not_equal, assert_false,
+    assert_in)
+
+import requests
+from requests import Session
 
 # handle py3 and py2 cases:
 try:
@@ -214,6 +218,8 @@ class TestLmApiWrapperCalls:
         self.send_response = self.p_send_response.start()
         self.p_is_successful = patch.object(models, 'is_successful')
         self.is_successful = self.p_is_successful.start()
+        self.p_get = patch.object(Session, 'get')
+        self.get = self.p_get.start()
 
         self.lm = LoadMaster("1.1.1.1", "bal", "1fourall")
 
@@ -222,6 +228,7 @@ class TestLmApiWrapperCalls:
         self.p__post.stop()
         self.p_send_response.stop()
         self.p_is_successful.stop()
+        self.p_get.stop()
 
     def test_stats(self):
         self.lm.stats()
@@ -392,3 +399,16 @@ class TestLmApiWrapperCalls:
         assert_false(lm1 > lm2)
         assert_false(lm1 <= lm2)
         assert_false(lm1 >= lm2)
+
+    def test_enable_api(self):
+        actual = self.lm.enable_api()
+        assert_true(actual)
+
+        self.lm.cert = "not None"
+        actual = self.lm.enable_api()
+        assert_true(actual)
+
+    def test_enable_api_exception(self):
+        self.get.side_effect = requests.exceptions.HTTPError
+        with assert_raises(exceptions.KempTechApiException) as e:
+            self.lm.enable_api()
